@@ -37,13 +37,10 @@ use strict;
 use warnings;
 
 use utf8;  # Convert all UTF-8 to Perl's internal representation.
-binmode STDIN,  ':utf8';
-binmode STDOUT, ':utf8';
-binmode STDERR, ':utf8';
 
 # --------------------------------------
 # Version
-use version; our $VERSION = qv(v1.0.3);
+use version; our $VERSION = qv(v1.0.4);
 
 # --------------------------------------
 # Modules
@@ -804,7 +801,7 @@ Sub::Starter - Creates a skeletal framework for Perl sub's.
 
 =head1 VERSION
 
-This document refers to Sub::Starter version v1.0.3
+This document refers to Sub::Starter version v1.0.4
 
 =head1 SYNOPSIS
 
